@@ -16,8 +16,7 @@
 #include "mixmod/Kernel/Algo/Algo.h"
 
 #include "mixmod/Utilities/Util.h"
-
-
+#include "Conversion.h"
 //default constructor
 ClusteringInputHandling::ClusteringInputHandling( XEM::ClusteringInput* cInput
                                                 , Rcpp::S4& algoOptions
@@ -91,7 +90,6 @@ void ClusteringInputHandling::setInitAlgo()
   if (Rf_isNull( algoOptions_.slot("initMethod") )) return;
   // get initialization algorithm name
   std::string init = Rcpp::as<std::string>(algoOptions_.slot("initMethod"));
-  
   // random initialization
   if (init == "random")
   {
@@ -105,30 +103,94 @@ void ClusteringInputHandling::setInitAlgo()
     setNbTryInInit();
     setNbIterationInInit();
     setEpsilonInInit();
+    cStrategy_->setStrategyInitName(XEM::SMALL_EM);
     return;
   }
   else if (init == "CEM")
   {
     setNbTry();
     setNbTryInInit();
+    cStrategy_->setStrategyInitName(XEM::CEM_INIT);
     return;
   }
   else if (init == "SEMMax")
   {
     setNbTry();
     setNbIterationInInit();
+    cStrategy_->setStrategyInitName(XEM::SEM_MAX);
     return;
   }
   else if (init == "parameter")
   {
-    throw(std::runtime_error("Error in InputHandling::run"
-                             " parameter initialization is not implemented"));
-    
+    //throw(std::runtime_error("Error in InputHandling::run"
+    //                         " parameter initialization is not implemented"));
+    //std::cout<<" parameter initialization is not implemented" <<std::endl;
+    cStrategy_->setStrategyInitName(XEM::USER);
+    Rcpp::S4 userParam(algoOptions_.slot("parameter"));
+    XEM::Parameter** paramArray1 = nullptr;
+    int nbCluster = 0;
+    int pbDim = 0;
+    Rcpp::NumericVector rProportions(userParam.slot("proportions"));
+    std::unique_ptr<double[]> proportions(new double[rProportions.size()]);
+    //Rcpp::NumericVector::iterator it;
+    Rcpp::NumericVector::iterator it;
+    int i; 
+    for(it = rProportions.begin(), i=0; it != rProportions.end(); ++it, i++)
+      { proportions[i] = (double)(*it);}
+
+    if(cInput_->getDataType() == XEM::QuantitativeData) {
+      Rcpp::NumericMatrix rMean(SEXP(userParam.slot("mean")));
+      Rcpp::List rVariance(userParam.slot("variance"));
+      nbCluster = rMean.nrow();
+      pbDim = rMean.ncol();
+      std::unique_ptr<double*[], XEM::TabDeleter<double>> cMean(Conversion::RcppMatrixToC2DArray(rMean),XEM::TabDeleter<double>(nbCluster));      
+      std::unique_ptr<double**[], XEM::VectTabDeleter<double>> cVariance(Conversion::RcppListOfMatrixToC3DArray(rVariance), XEM::VectTabDeleter<double>(nbCluster, pbDim)); 
+      paramArray1 = new XEM::Parameter*[1];
+      paramArray1[0] = new XEM::GaussianGeneralParameter(nbCluster, pbDim, cInput_->getModelType()[0], proportions.get(), cMean.get(), cVariance.get() );
+      cStrategy_->setTabInitParameter (paramArray1, 1);
+    } else if(cInput_->getDataType() == XEM::QualitativeData) {
+      Rcpp::IntegerVector rFactor(userParam.slot("factor"));
+      std::unique_ptr<int64_t[]> cFactor(new int64_t[rFactor.size()]);
+      //Rcpp::NumericVector::iterator it;
+      Rcpp::IntegerVector::iterator it2;
+      int k; 
+      for(it2 = rFactor.begin(), k=0; it2 != rFactor.end(); ++it2, k++)
+        { cFactor[k] = (int64_t)(*it2);}
+        
+      Rcpp::NumericMatrix rCenter(SEXP(userParam.slot("center")));
+      Rcpp::List rScatter(userParam.slot("scatter"));
+      nbCluster = rCenter.nrow();
+      pbDim = rCenter.ncol();
+      std::unique_ptr<double*[], XEM::TabDeleter<double>> cCenter(Conversion::RcppMatrixToC2DArray(rCenter),XEM::TabDeleter<double>(nbCluster));      
+      std::unique_ptr<double**[], XEM::VectTabDeleter<double>> cScatter(Conversion::RcppListOfMatrixToC3DArray(rScatter), XEM::VectTabDeleter<double>(nbCluster, pbDim)); 
+      paramArray1 = new XEM::Parameter*[1];
+      paramArray1[0] = new XEM::BinaryEkjhParameter(nbCluster, pbDim, cInput_->getModelType()[0], cFactor.get(), proportions.get(), cCenter.get(), cScatter.get() );
+      cStrategy_->setTabInitParameter (paramArray1, 1);
+    } else {
+      throw(std::runtime_error("Error in InputHandling::run"
+                             " parameter initialization for heterogeneous data  his not implemented"));      
+    }
   }
   else if (init == "partition")
   {
-    // TODO initialize partition
-    return;
+      Rcpp::IntegerVector rLabels(algoOptions_.slot("labels"));
+      int64_t nbSample = cInput_->getNbSample();
+      if(rLabels.size() != nbSample){
+        throw(std::runtime_error("Error in InputHandling::run"
+                                 "The size of labels vector doesn't match "
+                                 "the number of samples "));      
+      }
+      std::vector<int64_t> cLabelArray;
+      Rcpp::IntegerVector::iterator it;
+      int k; 
+      for(it = rLabels.begin(), k=0; it != rLabels.end(); ++it, k++)
+        { cLabelArray.push_back((int64_t)(*it));}
+      cStrategy_->setStrategyInitName(XEM::USER_PARTITION);
+      std::unique_ptr<XEM::Label> cLabel(new XEM::Label(nbSample));
+      cLabel->setLabel(cLabelArray, nbSample);
+      XEM::Partition* cPartition = new XEM::Partition(cLabel.get(),cInput_->getNbCluster(0));
+      cStrategy_->setInitPartition(cPartition, 0);
+        
   }
   //
   //  XEMStrategyInitName initName = cInput_->getStrategy()->getStrategyInit()->getStrategyInitName();
