@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Clustering/ClusteringMain.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -54,10 +54,20 @@ ClusteringMain::ClusteringMain(ClusteringInput * input, ClusteringOutput * outpu
 ClusteringMain::~ClusteringMain() {
 	// Deleting NULL or nullptr is fine.
 	// No check, because two calls of the destructor on the same object is a bug.
-	delete _output;
+  delete _output;
 }
 
-void ClusteringMain::run(int seed) {
+void ClusteringMain::run(int seed, IoMode iomode, int verbose, int massiccc) {
+#ifdef _OPENMP
+#pragma omp parallel
+#endif
+{
+	//TODO: naming conventions ? (this doesn't look good)
+	IOMODE = iomode;
+	VERBOSE = verbose;
+  MASSICCC = massiccc;
+
+  bool atLeastOneModelOk = false;
 
 	// Call randomize() function to use a random seed, or antiRandomize() for deterministic seed.
 	initRandomize(seed);
@@ -85,8 +95,8 @@ void ClusteringMain::run(int seed) {
 		}
 	}
 
-	Data* workingData = _input->getDataDescription().getData();
-	ClusteringStrategy* workingStrategy = _input->getStrategy();
+  Data* workingData = _input->getDataDescription().getData();
+  ClusteringStrategy* workingStrategy = _input->getStrategy();
 
 	// Prepare reduced data if qualitative data and DATA_REDUCE==true
 	std::vector<int64_t> correspondenceOriginDataToReduceData;
@@ -113,6 +123,7 @@ void ClusteringMain::run(int seed) {
 	}
 
 	// Initialize output [HACK: using pointer because of an error when retrieving CriterionOutput later]
+	//std::vector<CriterionName>* vCriterion = new std::vector<CriterionName>();
 	std::vector<CriterionName>* vCriterion = new std::vector<CriterionName>();
 	const int nbCriterion = _input->getCriterionName().size();
 	for (int iCriterion = 0; iCriterion<nbCriterion; iCriterion++)
@@ -121,18 +132,39 @@ void ClusteringMain::run(int seed) {
 
 	// Main loop : build and run every model, and incrementally fill output
 	// NOTE: potential parallelization here (OpenMP at least)
-	const int nbnbCluster = _input->getNbCluster().size();
-	for (int nbCluster_i= 0; nbCluster_i<nbnbCluster; nbCluster_i++) {
-		int64_t nbCluster = _input->getNbCluster()[nbCluster_i];
-		const int nbModel = _input->getModelType().size();
-		for (int nbModel_i=0; nbModel_i<nbModel; nbModel_i++) {
-			ModelType* modelType = _input->getModelType()[nbModel_i];
+
+	// Initialize timer info	
+	std::time_t startTime;
+	ofstream progressFile;
+	if (MASSICCC == 1) {
+		std::time(&startTime);
+	}
+
+  const int nbModel = _input->getModelType().size();
+  const int nbnbCluster = _input->getNbCluster().size();
+#ifdef _OPENMP
+#pragma omp critical
+#endif
+  _output->clusteringModelOutputResize(nbModel * nbnbCluster);
+#ifdef _OPENMP
+  omp_set_num_threads(1); // Force only 1 threads while it's not working like it should... Remove this to enable "export OMP_NUM_THREADS"
+#pragma omp for collapse(2)
+#endif
+  for (int nbCluster_i = 0; nbCluster_i < nbnbCluster; nbCluster_i++) {
+    for (int nbModel_i = 0; nbModel_i < nbModel; nbModel_i++) {
+      int64_t nbCluster = _input->getNbCluster()[nbCluster_i];
+      //Write progress in algo, not in this loop if both equals 1
+      if (MASSICCC == 1 && nbnbCluster == 1 && nbModel == 1) {
+        MASSICCC = 10;
+      }
+      ModelType* modelType = _input->getModelType()[nbModel_i];
+      
 
 			//-----------------
 			// 1. Create model
 			//-----------------
 
-			if (VERBOSE)
+			if (VERBOSE == 1)
 				std::cout << "Model name : "
 					<< ModelNameToString(modelType->getModelName()) << std::endl;
 
@@ -160,7 +192,7 @@ void ClusteringMain::run(int seed) {
 				workingStrategy->run(model);
 			}
 			catch (Exception& e) {
-				if (VERBOSE) {
+				if (VERBOSE == 1) {
 					Error error(e);
 					error.run();
 				}
@@ -169,7 +201,7 @@ void ClusteringMain::run(int seed) {
 			catch (...) {
 				Exception * unknown = new OtherException(UnknownReason);
 				model->setError(*unknown);
-				delete unknown;
+        delete unknown;
 			}
 
 			//--------------------
@@ -177,8 +209,9 @@ void ClusteringMain::run(int seed) {
 			//--------------------
 
 			ClusteringModelOutput* cmoutput = new ClusteringModelOutput(model);
-			_output->addEstimation(cmoutput);
+			_output->addEstimation(cmoutput, nbModel_i + nbCluster_i * nbModel);
 			if (model->getErrorType() == NOERROR) {
+			  atLeastOneModelOk = true;
 				// Loop over criterion name
 				for (std::vector<CriterionName>::const_iterator it= vCriterion->begin(); it != vCriterion->end(); it++) {
 					CriterionName criterion = *it;
@@ -220,18 +253,51 @@ void ClusteringMain::run(int seed) {
 						CriterionOutput(criterion, 0.0, model->getErrorType()));
 				}
 			}
+      
+      //Compute Entropy if needed (for massiccc's visualization)
+      if (MASSICCC == 1 || MASSICCC == 10 || MASSICCC == 11) {
+        vector< vector<double> > entropyM = model->getEntropyMatrix();
+        int nbVariables = model->getData()->getPbDimension();
+        ofstream entropyFile;
+        entropyFile.open ("entropy" + std::to_string(nbModel_i + 1 + nbCluster_i * nbModel) + ".txt");
+        for (int j = 0; j < nbVariables; j++) {
+          for (int l = 0; l < nbCluster; l++) {
+            entropyFile << entropyM[j][l] << "  ";
+          }
+          entropyFile << endl;
+        } 
+        entropyFile.close();
+      }
 
 			// model cannot be null (especially when we'll use enum class)
-			delete model;
+      delete model;
+			//Write progress in file
+			if (MASSICCC == 1) {
+				progressFile.open ("progress.json");
+				progressFile << "{ \"Progress\" :  " << ((double)nbModel_i + 1 + (double)nbCluster_i * (double)nbModel)/((double)nbModel * (double)nbnbCluster) * 100.0;
+				std::time_t currTime;
+				std::time(&currTime);
+				double timePerModel = std::difftime(currTime, startTime) / ((double)nbModel_i + 1 + (double)nbCluster_i * (double)nbModel);
+				progressFile << ", \"Estimated remaining time\" : " << timePerModel * (nbModel - nbModel_i - 1) +  (nbnbCluster - nbCluster_i - 1) * nbModel * timePerModel << " } ";
+				progressFile.close();
+			}
 		}
 	}
 
+
 	// Conditionally release memory
-	if (_input->getKnownLabelDescription()) delete workingKnownPartition;
-	if (_input->getDataType() == QualitativeData && DATA_REDUCE) {
-		delete workingData;
-		delete workingStrategy;
-	}
+  if (_input->getKnownLabelDescription()) delete workingKnownPartition;
+  if (_input->getDataType() == QualitativeData && DATA_REDUCE) {
+    delete workingData;
+    delete workingStrategy;
+  }
+//delete vCriterion;
+
+  if (!atLeastOneModelOk){
+    THROW(OtherException, AllModelsGotErros);
+  }
+
+}
 }
 
 }
