@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Clustering/ClusteringMain.h  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -53,7 +53,7 @@ public:
 	virtual ~ClusteringMain();
 
 	/// Run clustering(s) task(s) described by _input. Fill _output.
-	void run(int seed = -1);
+	void run(int seed = -1, IoMode iomode = IoMode::NUMERIC, int verbose = 0, int massiccc = 0);
 
 	/// Return pointer to input
 	ClusteringInput * getInput() const;
