@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Clustering/ClusteringStrategy.h  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -37,7 +37,7 @@ class Data;
 class Model;
 class Partition;
 
-/** 
+/**
  \class XEMClusteringOutput
  Main class for Mixmod Strategy
  @author F. Langrognet
@@ -68,7 +68,7 @@ public:
 	void setStrategyInit(ClusteringStrategyInit * iStrategyInit);
 
 	/// setStrategyInit
-	void setStrategyInit(StrategyInitName  initName, Data *& data, int64_t nbNbCluster, 
+	void setStrategyInit(StrategyInitName  initName, Data *& data, int64_t nbNbCluster,
 			int64_t * tabNbCluster, ModelType * modelType);
 
 	/// setStrategyInitName
@@ -149,7 +149,7 @@ public:
 
 	/// Input strategy (FLAT FORMAT)
 	// TODO XEMInput : a enlever
-	void input_FLAT_FORMAT(std::ifstream & fi, Data *& data, int64_t nbNbCluster, 
+	void input_FLAT_FORMAT(std::ifstream & fi, Data *& data, int64_t nbNbCluster,
 			int64_t * tabNbCluster, ModelType * modelType);
 
 	/// Run method
@@ -176,7 +176,8 @@ private:
 	/// Table of algorithm
 	std::vector<Algo*> _tabAlgo;    // aggregate
 
-	void oneTry(Model *& model) const;
+  /// One try (init+algo(s))
+	void oneTry(Model *& model, bool doThrow=false) const;
 };
 
 inline const ClusteringStrategyInit * ClusteringStrategy::getStrategyInit() const {
