@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/DiscriminantAnalysis/Learn/LearnMain.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -67,10 +67,16 @@ LearnMain::~LearnMain() {
 //---
 //run
 //---
-void LearnMain::run(int seed) {
+void LearnMain::run(int seed, IoMode iomode, int verbose, int massiccc) {
 	//--------------------------------------------------------------------
 	// Important : Call randomize function to change random seed or not ...
 	//---------------------------------------------------------------------
+	
+//TODO: naming conventions ? (this doesn't look good)
+	IOMODE = iomode;
+	VERBOSE = verbose;
+  MASSICCC = massiccc;
+
 	initRandomize(seed);
 
 	if (!_input) {
@@ -179,7 +185,7 @@ void LearnMain::run(int seed) {
 		}
 		catch (Exception&errorType) {
 			
-			if (VERBOSE) {
+			if (VERBOSE == 1) {
 				Error error(errorType);
 				error.run();
 			}
@@ -204,6 +210,13 @@ void LearnMain::run(int seed) {
 	// get criterion names
 	std::vector<CriterionName> const & criterion = _input->getCriterionName();
 
+	// Initialize timer info	
+	std::time_t startTime;
+	ofstream progressFile;
+	if (MASSICCC == 1) {
+		std::time(&startTime);
+	}
+
 	// loop over all models
 	for (unsigned int iModel = 0; iModel < nbEstimation; iModel++) {
 		// check whether error occurred for that model
@@ -236,8 +249,20 @@ void LearnMain::run(int seed) {
 				case UNKNOWN_CRITERION_NAME: THROW(OtherException, internalMixmodError);
 				default: THROW(OtherException, internalMixmodError);
 				}
-			} // end iCriterion
-		}
+
+        //Write progress in file
+        if (MASSICCC == 1) {
+          progressFile.open ("progress.json");
+          progressFile << "{ \"Progress\" :  " << ((double)iCriterion + 1 + (double)iModel * (double)criterion.size())/((double)criterion.size() * (double)nbEstimation) * 100.0;
+          std::time_t currTime;
+          std::time(&currTime);
+          double timePerModel = std::difftime(currTime, startTime) / ((double)iCriterion + 1 + (double)iModel * (double)criterion.size());
+          progressFile << ", \"Estimated remaining time\" : " << timePerModel * (criterion.size() - iCriterion - 1) +  (nbEstimation - iModel - 1) * criterion.size() * timePerModel << " } ";
+          progressFile.close();
+        }
+
+      } // end iCriterion
+    }
 		else { // set criterion error
 			// loop over criterion name
 			for (unsigned int iCriterion = 0; iCriterion < criterion.size(); iCriterion++) {
