@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/DiscriminantAnalysis/Learn/LearnMain.h  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -63,7 +63,7 @@ public:
 	Input * getInput();
 
 	/// Run method
-	void run(int seed = -1);
+	void run(int seed = -1, IoMode iomode = IoMode::NUMERIC, int verbose = 0, int massiccc = 0);
 	void setOutputNull();
 
 private:
