@@ -1,12 +1,12 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/Criterion/CVCriterion.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
 /***************************************************************************
     This file is part of MIXMOD
-
+    
     MIXMOD is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -20,7 +20,7 @@
     You should have received a copy of the GNU General Public License
     along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.
 
-    All informations available on : http://www.mixmod.org
+    All informations available on : http://www.mixmod.org                                                                                               
 ***************************************************************************/
 #include "mixmod/Kernel/Criterion/CVCriterion.h"
 #include "mixmod/Kernel/Criterion/CriterionOutput.h"
@@ -58,7 +58,8 @@ void CVCriterion::run(CriterionOutput & output) {
 	Exception* error = &NOERROR;
 
 	// copy of the current model
-	Model * CVModel = new Model(_model);
+	//Model * CVModel = new Model(_model);
+    std::unique_ptr<Model> CVModel(new Model(_model));
 	try {
 		double missClass = 0.0;
 		Data * data = _model->getData();
@@ -88,11 +89,11 @@ void CVCriterion::run(CriterionOutput & output) {
 				_cvLabel[i] += 1; //because computeLabel returns an int. between 0 and nbCluster-1
 			}
 		}
-		delete CVModel;
+		//delete CVModel; //done by unique_ptr
 		value = missClass / data->_weightTotal;
 	}
 	catch (Exception&e) {
-		delete CVModel;
+      //delete CVModel; //done by unique_ptr
 		// add name to criterion output
 		output.setCriterionName(CV);
 		// add error to criterion output
@@ -152,8 +153,10 @@ void CVCriterion::createCVBlocks() {
 		if (_CVinitBlocks == CV_RANDOM) {
 			//cout<<"CVCriterion CV_RANDOM"<<endl;
 			// random
-			double * tabRandom = new double[weightTotal];
-			int64_t * tabIndex = new int64_t[weightTotal];
+			//double * tabRandom = new double[weightTotal];
+			//int64_t * tabIndex = new int64_t[weightTotal];
+          std::unique_ptr<double[]> tabRandom(new double[weightTotal]);
+		  std::unique_ptr<int64_t[]> tabIndex(new int64_t[weightTotal]);
 			index = 0;
 			for (i = 0; i < nbSample; i++) {
 				sumWeight = 0.0;
@@ -169,7 +172,7 @@ void CVCriterion::createCVBlocks() {
 				//cout<<"cout erreur 5 ds CVCriterion"<<endl;
 				THROW(OtherException, internalMixmodError);
 			}
-			quickSortWithOrder(tabRandom, tabIndex, 0, (weightTotal) - 1);
+			quickSortWithOrder(tabRandom.get(), tabIndex.get(), 0, (weightTotal) - 1);
 
 			int64_t nbElt = (int64_t) (floor(((double) (weightTotal)) / (double) (_nbCVBlock)));
 			int64_t remaining = weightTotal - nbElt*_nbCVBlock;
@@ -270,8 +273,8 @@ void CVCriterion::createCVBlocks() {
 					delete pelem;
 				}
 			} // end for v
-			delete[] tabRandom;
-			delete[] tabIndex;
+			//delete[] tabRandom; //done by unique_ptr
+			//delete[] tabIndex; //done by unique_ptr
 		}
 			//------------------------------
 		else if (_CVinitBlocks == CV_DIAG) {
