@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/IO/Input.h  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -121,10 +121,10 @@ public:
 	std::vector<ModelType*> getModelType() const;
 
 	/// setModelType
-	/*virtual*/ void setModelType(const ModelType * modelType, unsigned int index);
+  /*virtual*/ void setModelType(const ModelType * modelType, unsigned int index);
 
 	/// insertModelType
-	/*virtual*/ void insertModelType(const ModelType * modelType, unsigned int index);
+  /*virtual*/ void insertModelType(const ModelType * modelType, unsigned int index);
 
 	/// add new model type (at the end)
 	/*virtual*/ void addModelType(const ModelType * modelType);
@@ -169,7 +169,7 @@ public:
 	void setKnownPartition(std::string iFileName);
 
 	/// insertKnownPartition
-	void insertKnownPartition(std::string iFileName);
+	void insertKnownPartition(NumericPartitionFile partitionFile);
 
 	/// removeKnownPartition
 	void removeKnownPartition();
