@@ -1,12 +1,12 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/Model/Model.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
 /***************************************************************************
     This file is part of MIXMOD
-
+    
     MIXMOD is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -20,7 +20,7 @@
     You should have received a copy of the GNU General Public License
     along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.
 
-    All informations available on : http://www.mixmod.org
+    All informations available on : http://www.mixmod.org                                                                                               
 ***************************************************************************/
 
 #include "mixmod/Kernel/Model/Model.h"
@@ -41,6 +41,9 @@
 #include "mixmod/Kernel/IO/CompositeData.h"
 #include "mixmod/Kernel/IO/Partition.h"
 #include "mixmod/Kernel/IO/LabelDescription.h"
+#include "mixmod/Matrix/Matrix.h"
+#include "mixmod/Kernel/IO/Sample.h"
+#include "mixmod/Kernel/IO/BinarySample.h"
 #include <string.h>
 
 namespace XEM {
@@ -441,9 +444,9 @@ int64_t Model::getLabelByMAPOrKnownPartition(int64_t i) {
 
 	if (res == -1) {
 
-		if (VERBOSE)
+		if (VERBOSE == 1)
 			// label couldn't be found
-			cout << "internalMixmodError ds Model::getLabelByMAPOrKnownPartition, i=" << i << endl;
+			cout << "internalMixmodError in Model::getLabelByMAPOrKnownPartition, i=" << i << endl;
 
 		THROW(OtherException, internalMixmodError);
 	}
@@ -541,18 +544,160 @@ double Model::getEntropy() {
 	// Compute entropy: sum[tik * log(tik)] //
 	for (i = 0; i < _nbSample; i++) {
 		// ajout du 16/06/2004 : ligne suivante : on ajoute uniqt si le label est inconnu
-		if (!_tabZiKnown[i]) {
-			for (k = 0; k < _nbCluster; k++) {
-				if (_tabTik[i][k] > 0 && _tabTik[i][k] != 1) {
-					entropy += _tabTik[i][k] * log(_tabTik[i][k]) * _data->_weight[i];
-				}
-			}
-		}
-	}
+    if (!_tabZiKnown[i]) {
+      for (k = 0; k < _nbCluster; k++) {
+        if (_tabTik[i][k] > 0 && _tabTik[i][k] != 1) {
+          entropy += _tabTik[i][k] * log(_tabTik[i][k]) * _data->_weight[i];
+        }
+      }
+    }
+  }
 
 	return -entropy;
 }
 
+//------------
+// get entropy matrix (for massiccc's visualization)
+//------------
+vector< vector<double> > Model::getEntropyMatrix() {
+
+  // Initialization //
+  int nbVariables = _parameter->getModel()->getData()->getPbDimension();
+  vector< vector<double> > entropyM(nbVariables, vector<double>(_nbCluster));
+  vector< vector<double> > tabTikj(_nbSample, vector<double>(_nbCluster));
+  double sum = 0.0;
+  double nlnk = _nbSample * log(_nbCluster);
+
+  for (int64_t j = 0; j < nbVariables; j++) {
+    if (isHeterogeneous(_modelType->_nameModel)) {
+      CompositeParameter * cParameter = dynamic_cast<CompositeParameter*> (_parameter);
+      //Binary Parameter
+      BinaryParameter * bParameter = cParameter->getBinaryParameter();
+      int64_t bPbDimension = bParameter->getPbDimension();
+      if (j < bPbDimension) {
+        double *** scatter = bParameter->scatterToArray();
+        for (int64_t i = 0; i < _nbSample; i++) {
+          for (int64_t k = 0; k < _nbCluster; k++) {
+            int64_t tabNbModality = bParameter->getTabNbModality()[j];
+            int64_t tabDataValue = bParameter->getModel()->getBinaryData()->getDataMatrix()[i]->getBinarySample()->getTabValue()[j];
+            double prod = 1.0;
+            for (int64_t m = 0; m < tabNbModality; m++) {
+              if (tabDataValue == (m + 1)) {
+                if (bParameter->getTabCenter()[k][j] == (m + 1)) {
+                  prod = prod * ((1 - scatter[k][j][m]));
+                }
+                else {
+                  prod = prod * (scatter[k][j][m] / (tabNbModality - 1));
+                }
+              }
+            }
+            tabTikj[i][k] = bParameter->getTabProportion()[k] * prod;
+            sum += tabTikj[i][k];
+          }
+          for (int64_t k = 0; k < _nbCluster; k++) {
+            tabTikj[i][k] = tabTikj[i][k] / sum;
+          }
+          sum = 0.0;
+        }
+        for (int64_t l = 0; l < _nbCluster; l++) {
+          for (int64_t m = 0; m < bPbDimension; m++) {
+            delete[] scatter[l][m];
+          }
+          delete[] scatter[l];
+        }
+        delete[] scatter;
+      }
+      else {
+        //Gaussian Parameter
+        GaussianEDDAParameter * gParameter = dynamic_cast<GaussianEDDAParameter*> (cParameter->getGaussianParameter());
+        int gPbDimension = gParameter->getPbDimension();
+        double ** tabData = gParameter->getModel()->getGaussianData()->getYStore();
+        for (int64_t i = 0; i < _nbSample; i++) {
+          for (int64_t k = 0; k < _nbCluster; k++) {
+            double ** store = gParameter->getTabSigma()[k]->storeToArray();
+            tabTikj[i][k] = gParameter->getTabProportion()[k] * 1.0/(sqrt(2.0*XEMPI)*sqrt(store[j - bPbDimension][j - bPbDimension])) * exp(-pow(tabData[i][j - bPbDimension] - gParameter->getTabMean()[k][j - bPbDimension],2)/(2*store[j - bPbDimension][j - bPbDimension]));
+            sum += tabTikj[i][k];
+            for (int64_t l = 0; l < gPbDimension; l++) {
+              delete[] store[l];
+            }
+            delete[] store;
+          }
+          for (int k = 0; k < _nbCluster; k++) {
+            tabTikj[i][k] = tabTikj[i][k] / sum;
+          }
+          sum = 0.0;
+        }
+      }
+    }
+    else {
+      if (isBinary(_modelType->_nameModel)) {
+        BinaryParameter * bParameter = dynamic_cast<BinaryParameter*> (_parameter);
+        double *** scatter = bParameter->scatterToArray();
+        for (int64_t i = 0; i < _nbSample; i++) {
+          int tabNbModality = bParameter->getTabNbModality()[j];
+          int tabDataValue = bParameter->getModel()->getBinaryData()->getDataMatrix()[i]->getBinarySample()->getTabValue()[j];
+          for (int64_t k = 0; k < _nbCluster; k++) {
+            double prod = 1.0;
+            for (int64_t m = 0; m < tabNbModality; m++) {
+              if (tabDataValue == (m + 1)) {
+                if (bParameter->getTabCenter()[k][j] == (m + 1)) {
+                  prod = prod * ((1 - scatter[k][j][m]));
+                }
+                else { //Verifier avec Gilles ou Christophe cette partie, c'est pas sur par rapport au pdf...
+                  prod = prod * (scatter[k][j][m] / (tabNbModality - 1));
+                }
+              }
+            }
+            tabTikj[i][k] = bParameter->getTabProportion()[k] * prod;
+            sum += tabTikj[i][k];
+          }
+          for (int64_t k = 0; k < _nbCluster; k++) {
+            tabTikj[i][k] = tabTikj[i][k] / sum;
+          }
+          sum = 0.0;
+        }
+        for (int64_t l = 0; l < _nbCluster; l++) {
+          for (int64_t m = 0; m < nbVariables; m++) {
+            delete[] scatter[l][m];
+          }
+          delete[] scatter[l];
+        }
+        delete[] scatter;
+
+      }
+      else {
+        GaussianEDDAParameter * gParameter = dynamic_cast<GaussianEDDAParameter*> (_parameter);
+        double ** tabData = gParameter->getModel()->getGaussianData()->getYStore();
+        for (int64_t i = 0; i < _nbSample; i++) {
+          for (int64_t k = 0; k < _nbCluster; k++) {
+            double ** store = gParameter->getTabSigma()[k]->storeToArray();
+            tabTikj[i][k] = gParameter->getTabProportion()[k] * (1.0/(sqrt(2.0*XEMPI*store[j][j])) * exp(-pow(tabData[i][j] - gParameter->getTabMean()[k][j],2)/(2*store[j][j])));
+            sum += tabTikj[i][k];
+            for (int64_t l = 0; l < nbVariables; l++) {
+              delete[] store[l];
+            }
+            delete[] store;
+          }
+          for (int64_t k = 0; k < _nbCluster; k++) {
+            tabTikj[i][k] = tabTikj[i][k] / sum;
+          }
+          sum = 0.0;
+        }
+
+      }
+    }
+
+    for (int64_t k = 0; k < _nbCluster; k++) {
+      for (int64_t i = 0; i < _nbSample; i++) {
+        if (tabTikj[i][k] == 0.0) tabTikj[i][k] = 1.0;
+        entropyM[j][k] += - tabTikj[i][k] * log(tabTikj[i][k]);
+      }
+      entropyM[j][k] = entropyM[j][k] / nlnk;
+    }
+  }
+  return entropyM;
+}
+
 // set parameters
 void Model::setParameter(Parameter * parameter) {
 	if (_parameter) delete _parameter;
@@ -766,7 +911,7 @@ void Model::initRANDOM(int64_t nbTry) {
 	// 1. InitForInitRandom
 	//---------------------
 	_parameter->initForInitRANDOM();
-
+	
 	// 1rst RANDOM
 	//-------------
 	randomForInitRANDOMorUSER_PARTITION(
@@ -1241,6 +1386,10 @@ void Model::Estep() {
 	//---------------
 	int64_t k;
 	int64_t i;
+
+	// Initialize timer info	
+	ofstream progressFile;
+
 	for (i = 0; i < _nbSample; i++) {
 		if (_tabSumF[i] == 0.0) {
 			_parameter->computeTikUnderflow(i, _tabTik);
@@ -1257,8 +1406,15 @@ void Model::Estep() {
 			for (k = 0; k < _nbCluster; k++) {
 				_tabCik[i][k] = _tabTik[i][k];
 			}
-		}
-	}
+    }
+    //Write progress in file
+    if (MASSICCC == 11) {
+      progressFile.open ("progress.json");
+      progressFile << "{ \"Progress\" :  " << (((double)i + 1)/((double)_nbSample) * 100.0)/2.0 << " }";
+      progressFile.close();
+    }
+
+  }
 	//4. compute nk
 	//------------
 	computeNk();
@@ -1361,6 +1517,10 @@ void Model::Cstep() {
 	int64_t k, kMax;
 	int64_t i;
 	double tikMax = 0;
+
+	// Initialize timer info	
+	ofstream progressFile;
+
 	for (i = 0; i < _nbSample; i++) {
 		if (!_tabZiKnown[i]) {
 			kMax = 0;
@@ -1376,6 +1536,12 @@ void Model::Cstep() {
 			}
 			_tabCik[i][kMax] = 1;
 		}
+    //Write progress in file
+    if (MASSICCC == 11) {
+      progressFile.open ("progress.json");
+      progressFile << "{ \"Progress\" :  " << 50 + (((double)i + 1)/((double)_nbSample) * 100.0)/2.0 << " }";
+      progressFile.close();
+    }
 	}
 
 	//update _tabNk
