@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/Parameter/BinaryEjParameter.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -183,15 +183,17 @@ double BinaryEjParameter::getPdf(Sample * x, int64_t kCluster) const {
 double BinaryEjParameter::getLogLikelihoodOne() const {
 	int64_t i;
 	int64_t j;
-	double logLikelihoodOne = 0.0, pdf, * Scatter;
-	Scatter = new double[_pbDimension];
-	int64_t * Center = new int64_t[_pbDimension];
-	double * tabNbSampleInMajorModality = new double[_pbDimension];
+	double logLikelihoodOne = 0.0, pdf; //, * Scatter;
+	std::unique_ptr<double[]> Scatter(new double[_pbDimension]);
+	//int64_t * Center = new int64_t[_pbDimension];
+    std::unique_ptr<int64_t[]> Center(new int64_t[_pbDimension]);
+	//double * tabNbSampleInMajorModality = new double[_pbDimension];
+	std::unique_ptr<double[]> tabNbSampleInMajorModality(new double[_pbDimension]);
 	int64_t nbSample = _model->getNbSample();
 	BinaryData * data = _model->getBinaryData();
 
 	// Compute Center fo One cluster //
-	getTabCenterIfOneCluster(Center, tabNbSampleInMajorModality);
+	getTabCenterIfOneCluster(Center.get(), tabNbSampleInMajorModality.get());
 
 	// Compute Scatter for One cluster //
 	for (j = 0; j < _pbDimension; j++) {
@@ -202,13 +204,13 @@ double BinaryEjParameter::getLogLikelihoodOne() const {
 
 	// Compute the log-likelihood for one cluster (k=1) //
 	for (i = 0; i < nbSample; i++) {
-		pdf = computePdfOneCluster(data->_matrix[i], Center, Scatter, _tabNbModality);
+      pdf = computePdfOneCluster(data->_matrix[i], Center.get(), Scatter.get(), _tabNbModality);
 		logLikelihoodOne += log(pdf) * data->_weight[i];
 	}
 
-	delete[] Center;
-	delete[] Scatter;
-	delete[] tabNbSampleInMajorModality;
+	//delete[] Center;
+	//delete[] Scatter;
+	//delete[] tabNbSampleInMajorModality;
 
 	return logLikelihoodOne;
 }
@@ -326,30 +328,28 @@ void BinaryEjParameter::editScatter(int64_t k) {
 // editScatter 
 //------------
 void BinaryEjParameter::editScatter(std::ofstream & oFile, int64_t k, bool text) {
-	int64_t j, h;
-	if (text) {
-		oFile << "\t\t\tScattering : \n";
-	}
-	for (j = 0; j < _pbDimension; j++) {
-		if (text) {
-			oFile << "\t\t\t\t\t";
-			;
-		}
-		for (h = 1; h <= _tabNbModality[j]; h++) {
-			if (h == _tabCenter[k][j]) {
-				oFile << _scatter[j] << "  ";
-			}
-			else {
-				oFile << _scatter[j] / (_tabNbModality[j] - 1) << "  ";
-			}
-		}
-		oFile << endl;
-	}
+  int64_t j, h;
+  if (text) {
+    oFile << "\t\t\tScattering : \n";
+  }
+  for (j = 0; j < _pbDimension; j++) {
+    if (text) {
+      oFile << "\t\t\t\t\t";
+      ;
+    }
+    for (h = 1; h <= _tabNbModality[j]; h++) {
+      if (h == _tabCenter[k][j])
+				putDoubleInStream(oFile, _scatter[j], "  ");
+      else
+				putDoubleInStream(oFile, _scatter[j] / (_tabNbModality[j] - 1), "  ");
+    }
+    oFile << endl;
+  }
 }
 
 // Read Scatter in input file
 //---------------------------
-void BinaryEjParameter::inputScatter(std::ifstream & fi) {
+void BinaryEjParameter::inputScatter(std::ifstream & fi, int64_t k) {
 	THROW(OtherException, internalMixmodError);
 }
 
