@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/Parameter/BinaryEjParameter.h  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -95,7 +95,7 @@ public:
 	void editScatter(std::ofstream & oFile, int64_t k, bool text = false);
 
 	// Read Scatter in input file
-	void inputScatter(std::ifstream & fi);
+	void inputScatter(std::ifstream & fi, int64_t k);
 	void inputScatter(double *** scatters);
 
 	double *** scatterToArray() const;
