@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/Parameter/BinaryEkjhParameter.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -277,14 +277,19 @@ double BinaryEkjhParameter::getPdf(Sample * x, int64_t kCluster) const {
 double BinaryEkjhParameter::getLogLikelihoodOne() const {
 	int64_t i;
 	int64_t j, h;
-	double logLikelihoodOne = 0.0, pdf, ** Scatter;
-	Scatter = new double*[_pbDimension];
+	double logLikelihoodOne = 0.0, pdf; //, ** Scatter;
+	//Scatter = new double*[_pbDimension];
+    std::unique_ptr<double*[], TabDeleter<double>>  Scatter(new double*[_pbDimension], TabDeleter<double>(_pbDimension));
 	for (j = 0; j < _pbDimension; j++) {
 		Scatter[j] = new double[_tabNbModality[j]];
 	}
-	int64_t * Center = new int64_t[_pbDimension];
-	double * tabNbSampleInMajorModality = new double [_pbDimension];
-	double ** tabNbSamplePerModality = new double * [_pbDimension];
+
+	//int64_t * Center = new int64_t[_pbDimension];
+    std::unique_ptr<int64_t[]> Center(new int64_t[_pbDimension]);
+	//double * tabNbSampleInMajorModality = new double [_pbDimension];
+    std::unique_ptr<double[]> tabNbSampleInMajorModality(new double[_pbDimension]);
+	//double ** tabNbSamplePerModality = new double * [_pbDimension];
+    std::unique_ptr<double*[], TabDeleter<double>>  tabNbSamplePerModality(new double * [_pbDimension], TabDeleter<double>(_pbDimension));
 	for (j = 0; j < _pbDimension; j++) {
 		tabNbSamplePerModality[j] = new double[_tabNbModality[j]];
 	}
@@ -292,7 +297,7 @@ double BinaryEkjhParameter::getLogLikelihoodOne() const {
 	BinaryData * data = _model->getBinaryData();
 
 	// Compute Center fo One cluster //
-	getTabCenterIfOneCluster(Center, tabNbSampleInMajorModality, tabNbSamplePerModality);
+	getTabCenterIfOneCluster(Center.get(), tabNbSampleInMajorModality.get(), tabNbSamplePerModality.get());
 
 
 	// Compute Scatter for One cluster //
@@ -314,20 +319,20 @@ double BinaryEkjhParameter::getLogLikelihoodOne() const {
 	// Compute the log-likelihood for one cluster (k=1) //
 	//--------------------------------------------------//
 	for (i = 0; i < nbSample; i++) {
-		pdf = computePdfOneCluster(data->_matrix[i], Center, Scatter, _tabNbModality);
+      pdf = computePdfOneCluster(data->_matrix[i], Center.get(), Scatter.get(), _tabNbModality);
 		logLikelihoodOne += log(pdf) * data->_weight[i];
 	}
 
-	delete[] Center;
-	for (j = 0; j < _pbDimension; j++) {
-		delete[] Scatter[j];
-	}
-	delete [] Scatter;
-	for (j = 0; j < _pbDimension; j++) {
-		delete[] tabNbSamplePerModality[j];
-	}
-	delete[] tabNbSamplePerModality;
-	delete[] tabNbSampleInMajorModality;
+	//delete[] Center;
+	//for (j = 0; j < _pbDimension; j++) {
+	//	delete[] Scatter[j];
+	//}
+	//delete [] Scatter;
+	//for (j = 0; j < _pbDimension; j++) {
+	//	delete[] tabNbSamplePerModality[j];
+	//}
+	//delete[] tabNbSamplePerModality;
+	//delete[] tabNbSampleInMajorModality;
 
 	return logLikelihoodOne;
 }
@@ -450,34 +455,32 @@ void BinaryEkjhParameter::editScatter(std::ofstream & oFile, int64_t k, bool tex
 			oFile << "\t\t\t\t\t";
 			;
 		}
-		for (h = 0; h < _tabNbModality[j]; h++) {
-			oFile << _scatter[k][j][h] << "  ";
-		}
+		for (h = 0; h < _tabNbModality[j]; h++)
+			putDoubleInStream(oFile, _scatter[k][j][h], "  ");
 		oFile << endl;
 	}
 }
 
 // Read Scatter in input file
 //---------------------------
-void BinaryEkjhParameter::inputScatter(std::ifstream & fi) {
-	//Mise a jour de tabCenter, tabScatter et tabProportion
-	int64_t j, k, h;
-	for (k = 0; k < _nbCluster; k++) {
-		// Proportions //
-		fi >> _tabProportion[k];
+void BinaryEkjhParameter::inputScatter(std::ifstream & fi, int64_t k) {
+  //Mise a jour de tabCenter, tabScatter et tabProportion
+  int64_t j, h;
+  //for (k = 0; k < _nbCluster; k++) {
+  //  // Proportions //
+  //  fi >> _tabProportion[k];
 
-		// Center  //
-		for (j = 0; j < _pbDimension; j++) {
-			fi >> _tabCenter[k][j];
-		}
+  //  // Center  //
+  //  for (j = 0; j < _pbDimension; j++) {
+  //    fi >> _tabCenter[k][j];
+  //  }
 
-		// Scatter  //
-		for (j = 0; j < _pbDimension; j++) {
-			for (h = 0; h < _tabNbModality[j]; h++) {
-				fi >> _scatter[k][j][h];
-			}
-		}
-	} // end for k
+  // Scatter  //
+  for (j = 0; j < _pbDimension; j++) {
+    for (h = 0; h < _tabNbModality[j]; h++)
+			_scatter[k][j][h] = getDoubleFromStream(fi);
+  }
+  //} // end for k
 }
 
 // Read Scatter in input containers
