@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/Parameter/GaussianDiagParameter.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -30,6 +30,8 @@
 #include "mixmod/Kernel/Model/ModelType.h"
 #include "mixmod/Matrix/DiagMatrix.h"
 
+#include <memory>
+
 namespace XEM {
 
 /****************/
@@ -160,8 +162,10 @@ void GaussianDiagParameter::computeTabSigma() {
 	GaussianData * data = _model->getGaussianData();
 	double * tabNk = _model->getTabNk();
 	int64_t k;
-	DiagMatrix * B = new DiagMatrix(_pbDimension);
-	DiagMatrix * Bk = new DiagMatrix(_pbDimension);
+	//DiagMatrix * B = new DiagMatrix(_pbDimension);
+	//DiagMatrix * Bk = new DiagMatrix(_pbDimension);
+	std::unique_ptr<DiagMatrix> B(new DiagMatrix(_pbDimension));
+	std::unique_ptr<DiagMatrix>Bk(new DiagMatrix(_pbDimension));
 	double detB = 0.0; // Determinant of matrix B
 	int64_t iter = 5; // Number of iterations in iterative procedure 
 	//  double detDiagW;         // Determinant of diagonal matrix W
@@ -171,7 +175,8 @@ void GaussianDiagParameter::computeTabSigma() {
 	double power = 1.0 / _pbDimension;
 	double det = 0.0;
 	double logDet = 0.0;
-	double * W_k = new double[_pbDimension];
+	//double * W_k = new double[_pbDimension];
+	std::unique_ptr<double[]> W_k(new double[_pbDimension]);    
 	double * Shape_k;
 	double tmp;
 	int64_t p;
@@ -255,7 +260,7 @@ void GaussianDiagParameter::computeTabSigma() {
 			for (k = 0; k < _nbCluster; k++) {
 				//_tabShape[k] = _tabW[k]/_tabLambda[k]
 				Bk->equalToMatrixDividedByDouble(_tabWk[k], _tabLambda[k]);
-				(*B) += Bk; // B->operator+=(Bk) : B=somme sur k des Bk
+				(*B) += Bk.get(); // B->operator+=(Bk) : B=somme sur k des Bk
 			}
 			/* Compute det(B) */
 			NumericException error = NumericException(minDeterminantBValueError);
@@ -265,8 +270,8 @@ void GaussianDiagParameter::computeTabSigma() {
 			/* Compute Shape[k] and Lambda[k] */
 			for (k = 0; k < _nbCluster; k++) {
 				// W_k      = _tabWk[k]->getDiagonalValue();
-				_tabWk[k]->putDiagonalValueInStore(W_k);
-				_tabShape[k]->equalToMatrixDividedByDouble(B, detB);
+              _tabWk[k]->putDiagonalValueInStore(W_k.get());
+				_tabShape[k]->equalToMatrixDividedByDouble(B.get(), detB);
 				Shape_k = _tabShape[k]->getStore();
 				tmp = 0.0;
 				for (p = 0; p < _pbDimension; p++) {
@@ -294,9 +299,9 @@ void GaussianDiagParameter::computeTabSigma() {
 	}
 
 	updateTabInvSigmaAndDet();
-	delete Bk;
-	delete B;
-	delete [] W_k;
+	//delete Bk;
+	//delete B;
+	//delete [] W_k;
 }
 
 //-------------------
@@ -312,16 +317,19 @@ double GaussianDiagParameter::getLogLikelihoodOne() const {
 	int64_t i;
 	GaussianData * data = _model->getGaussianData();
 	double logLikelihoodOne; // Log-likelihood for k=1
-	double * Mean = new double[_pbDimension];
+	//double * Mean = new double[_pbDimension];
+	std::unique_ptr<double[]> Mean(new double[_pbDimension]);    
 	double ** y = data->_yStore;
 	double * yi;
-	DiagMatrix * Sigma = new DiagMatrix(_pbDimension);
-	DiagMatrix * W = new DiagMatrix(_pbDimension, 0.0);
+	//DiagMatrix * Sigma = new DiagMatrix(_pbDimension);
+	//DiagMatrix * W = new DiagMatrix(_pbDimension, 0.0);
+	std::unique_ptr<DiagMatrix> Sigma(new DiagMatrix(_pbDimension));
+	std::unique_ptr<DiagMatrix> W(new DiagMatrix(_pbDimension, 0.0));
 	double norme;
 	double * weight = data->_weight;
 	//  Mean Estimator (empirical estimator)
 	double totalWeight = data->_weightTotal;
-	computeMeanOne(Mean, weight, y, nbSample, totalWeight);
+	computeMeanOne(Mean.get(), weight, y, nbSample, totalWeight);
 	weight = data->_weight;
 
 	/* Compute the Cluster Scattering Matrix W */
@@ -338,13 +346,14 @@ double GaussianDiagParameter::getLogLikelihoodOne() const {
 
 	/* Compute determinant of diag(W) */
 	//logDet   = W->detDiag(minDeterminantDiagWValueError); //virtual
-	Sigma->equalToMatrixDividedByDouble(W, totalWeight); //virtual
+	Sigma->equalToMatrixDividedByDouble(W.get(), totalWeight); //virtual
 
 	// inverse of Sigma
 	//DiagMatrix * SigmaMoins1 = new DiagMatrix(_pbDimension);
-	Matrix * SigmaMoins1 = NULL;
+	Matrix * SigmaMoins1_p = NULL;
 	//SigmaMoins1->inverse(Sigma);// virtual
-	Sigma->inverse(SigmaMoins1); //construction de SigmaMoins1 dans la fonction inverse
+	Sigma->inverse(SigmaMoins1_p); //construction de SigmaMoins1 dans la fonction inverse
+    std::unique_ptr<Matrix> SigmaMoins1(SigmaMoins1_p);
 	NumericException error = NumericException(minDeterminantSigmaValueError);
 	double detSigma = Sigma->determinant(error); // virtual
 
@@ -362,11 +371,11 @@ double GaussianDiagParameter::getLogLikelihoodOne() const {
 	logLikelihoodOne += totalWeight * (data->getPbDimensionLog2Pi() + log(detSigma));
 	logLikelihoodOne *= -0.5;
 
-	delete W;
-	delete Sigma;
-	delete SigmaMoins1;
+	//delete W;
+	//delete Sigma;
+	//delete SigmaMoins1;
 
-	delete[] Mean;
+	//delete[] Mean;
 	return logLikelihoodOne;
 }
 
