@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/Parameter/GaussianSphericalParameter.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -180,17 +180,20 @@ double GaussianSphericalParameter::getLogLikelihoodOne() const {
 	int64_t i;
 	GaussianData * data = _model->getGaussianData();
 	double logLikelihoodOne; // Log-likelihood for k=1
-	double * Mean = new double[_pbDimension];
+	//double * Mean = new double[_pbDimension];
+    std::unique_ptr<double[]> Mean(new double[_pbDimension]);
 	double ** y = data->_yStore;
 	double * yi;
-	SphericalMatrix * Sigma = new SphericalMatrix(_pbDimension);
-	SphericalMatrix * W = new SphericalMatrix(_pbDimension);
+	//SphericalMatrix * Sigma = new SphericalMatrix(_pbDimension);
+	//SphericalMatrix * W = new SphericalMatrix(_pbDimension);
+	std::unique_ptr<SphericalMatrix> Sigma(new SphericalMatrix(_pbDimension));
+	std::unique_ptr<SphericalMatrix> W(new SphericalMatrix(_pbDimension));
 	double norme;
 	double * weight = data->_weight;
 
 	//  Mean Estimator (empirical estimator)
 	double totalWeight = data->_weightTotal;
-	computeMeanOne(Mean, weight, y, nbSample, totalWeight);
+	computeMeanOne(Mean.get(), weight, y, nbSample, totalWeight);
 	weight = data->_weight;
 
 	/* Compute the Cluster Scattering Matrix W */
@@ -199,7 +202,7 @@ double GaussianSphericalParameter::getLogLikelihoodOne() const {
 	for (i = 0; i < nbSample; i++) {
 		yi = y[i];
 		for (p = 0; p < _pbDimension; p++) {
-			xiMoinsMuk[p] = yi[p] - Mean[p];
+          xiMoinsMuk[p] = yi[p] - Mean.get()[p];
 		}
 		W->add(xiMoinsMuk, weight[i]);
 	}
@@ -207,16 +210,16 @@ double GaussianSphericalParameter::getLogLikelihoodOne() const {
 	/* Compute determinant of diag(W) */
 	//  logDet   = W->detDiag(minDeterminantDiagWValueError);  // virtual
 	//  detDiagW = powAndCheckIfNotNull(logDet ,1.0/_pbDimension);
-	Sigma->equalToMatrixDividedByDouble(W, totalWeight); // virtual
+	Sigma->equalToMatrixDividedByDouble(W.get(), totalWeight); // virtual
 
 	// inverse of Sigma
 	//XEMSphericalMatrix * SigmaMoins1 = new XEMSphericalMatrix( _pbDimension);
-	Matrix * SigmaMoins1 = NULL;
+	Matrix * SigmaMoins1_p = NULL;
 	//SigmaMoins1->inverse(Sigma);// virtual
 	//cout<<"S"<<endl;
 	//Sigma->edit(cout,"");
-
-	Sigma->inverse(SigmaMoins1);
+	Sigma->inverse(SigmaMoins1_p);//actually SigmaMoins1 are created by inverse() with "New Matrix..."
+    std::unique_ptr<Matrix> SigmaMoins1(SigmaMoins1_p); //instead of the final delete (still ugly, althtough better than the final delete...)
 	//cout<<"S-1"<<endl;
 	//SigmaMoins1->edit(cout,"");
 	NumericException error = NumericException(minDeterminantSigmaValueError);
@@ -227,7 +230,7 @@ double GaussianSphericalParameter::getLogLikelihoodOne() const {
 	for (i = 0; i < nbSample; i++) {
 		yi = y[i];
 		for (p = 0; p < _pbDimension; p++) {
-			xiMoinsMuk[p] = yi[p] - Mean[p];
+          xiMoinsMuk[p] = yi[p] - Mean.get()[p];
 		}
 		norme = SigmaMoins1->norme(xiMoinsMuk); // virtual
 		logLikelihoodOne += norme * weight[i];
@@ -236,11 +239,11 @@ double GaussianSphericalParameter::getLogLikelihoodOne() const {
 	logLikelihoodOne += totalWeight * (data->getPbDimensionLog2Pi() + log(detSigma));
 	logLikelihoodOne *= -0.5;
 
-	delete[] Mean;
+	//delete[] Mean;
 
-	delete W;
-	delete Sigma;
-	delete SigmaMoins1;
+	//delete W;
+	//delete Sigma;
+	//delete SigmaMoins1;
 
 	return logLikelihoodOne;
 }
