@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Matrix/Matrix.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -54,9 +54,8 @@ void Matrix::edit(std::ostream& flux, std::string before) {
 	double** store = storeToArray();
 	for (i = 0; i < _s_pbDimension; i++) {
 		flux << '\t' << '\t' << '\t' << '\t';
-		for (j = 0; j < _s_pbDimension; j++) {
-			flux << store[i][j] << " ";
-		}
+		for (j = 0; j < _s_pbDimension; j++)
+			putDoubleInStream(flux, store[i][j], " ");
 		flux << '\n';
 	}
 
