@@ -1,12 +1,12 @@
 /***************************************************************************
                              SRC/mixmod/Utilities/Util.h  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
 /***************************************************************************
     This file is part of MIXMOD
-
+    
     MIXMOD is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -20,7 +20,7 @@
     You should have received a copy of the GNU General Public License
     along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.
 
-    All informations available on : http://www.mixmod.org
+    All informations available on : http://www.mixmod.org                                                                                               
 ***************************************************************************/
 /** @file Util.h
  *  @brief Constants definitions, various utilities to describe models, and others...
@@ -36,7 +36,9 @@
 #ifndef WANT_MATH
 #define WANT_MATH
 #endif
-
+#ifdef _OPENMP
+#include <omp.h>
+#endif
 /** Exception Classes*/
 #include "mixmod/Utilities/exceptions/Exception.h"
 #include "mixmod/Utilities/exceptions/DCVException.h"
@@ -63,6 +65,7 @@
 // Need matrix applications
 #include "mixmod/Utilities/maths/SelectLibrary.h"
 
+
 namespace XEM {
 
 //Macro for throw
@@ -87,7 +90,21 @@ const int DEBUG = 0; // >0 for debug information
                      // 1 : param debug
                      // 2 : param and fik, tik, zik debug
 const bool DATA_REDUCE = false; // do not reduce binary data (bug with weights, I don't want to try to fix it.....)
-const bool VERBOSE = false;    // print various execution traces (labels, errors...)
+
+extern int VERBOSE;    // 0 = No VERBOSE, 1 = print various execution traces (labels, errors...)
+extern int MASSICCC;   // 0 = no output, 1 = output for massiccc purpose (progress file, entropy computation...), (11 = 1 for predict)
+enum class IoMode // How to read/Write data in files ? (binary or ascii format)
+{
+	NUMERIC,
+	BINARY
+};
+extern IoMode IOMODE; // BINARY for exact values (in hexa) in ouputs files for non regression tests; ASCII for human-readable.
+
+//write floating point number into stream (usually a file)
+void putDoubleInStream(std::ostream& output, double value, std::string appendChars = "");
+
+// retrieve floating point number from stream (usually a file)
+double getDoubleFromStream(std::istream& input);
 
 /// Define number of maximum samples
 const int64_t maxNbSample = 1000000;     // Maximum sample size
@@ -667,6 +684,8 @@ TypePartition::TypePartition StringToTypePartition(const std::string & strTypePa
 
 //StrategyInitNameToString
 std::string StrategyInitNameToString(const StrategyInitName & strategyInitName);
+//StrategyInitNameToString for 3rd party env (R, Py, etc.)
+std::string StrategyInitNameToStringApp(const StrategyInitName & strategyInitName);
 
 //StringToStrategyInitName
 StrategyInitName StringToStrategyInitName(const std::string & str);
@@ -809,14 +828,55 @@ template<typename T> void editTab(T ** tab, int64_t dim1, int64_t dim2,
 	for (i = 0; i < dim1; i++) {
 		p_tab_i = *p_tab;
 		flux << before;
-		for (j = 0; j < dim2; j++) {
-			flux << p_tab_i[j] << sep;
-		}
+		for (j = 0; j < dim2; j++)
+      putDoubleInStream(flux, p_tab_i[j], sep);
 		flux << endl;
 		p_tab++;
 	}
 }
 
+//Deleters for unique_ptr
+template<typename T> 
+ struct TabDeleter {
+  TabDeleter(int64_t size) : _size(size){};
+  int64_t _size;
+  void operator()(T** p) {
+    for(int64_t i=0;i<_size;i++){
+      delete[] p[i];
+    };
+    delete[] p;
+
+  }
+};
+
+template<typename T> 
+ struct VectTabDeleter {
+ VectTabDeleter(int64_t sizeV, int64_t sizeT) : _sizeV(sizeV), _sizeT(sizeT) {};
+  int64_t _sizeV; 
+  int64_t _sizeT;  
+  void operator()(T*** p) {
+    for(int64_t v=0;v<_sizeV;v++){
+      for(int64_t i=0;i<_sizeT;i++){
+        delete[] p[v][i];
+      };
+      delete[] p[v];
+    }
+    delete[] p;
+
+  }
+};
+ 
+template<typename T> 
+ struct IfChangedDeleter {
+  IfChangedDeleter(T* initial) : _initial(initial){};
+  T* _initial;
+  void operator()(T* p) {
+    if(p != _initial) delete p;
+  }
+};
+
+
+ 
 // move on a file until *what* is reached
 void moveUntilReach(std::ifstream & fi, std::string what = "datafile");
 
@@ -843,6 +903,7 @@ void inputCVinitBlocks(std::ifstream & fi, CVinitBlocks cVinitBlocks);
 
 void inputDCVinitBlocks(std::ifstream & fi, DCVinitBlocks dCVinitBlocks);
 
+ 
 }
 
 #endif
