@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Utilities/exceptions/OtherException.h  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -37,7 +37,7 @@ namespace XEM {
 class OtherException : public Exception {
 
 public:
-	
+
 	OtherException(std::string file, int line, OtherError error) throw ();
 	OtherException(OtherError) throw ();
 	Exception * clone() throw ();
@@ -62,14 +62,16 @@ public:
 		m.insert(std::make_pair(UnknownReason, "Error occurred due to unknown reason."));
 		m.insert(std::make_pair(internalMixmodError, "Internal error in mixmod sofware"));
 		m.insert(std::make_pair(FunctionNotYetImplemented, "Function that is called is not yet implemented"));
-
+		m.insert(std::make_pair(AllModelsGotErros, "All models got errors"));
+		m.insert(std::make_pair(AllTriesGotErros, "All tries got errors"));
+		m.insert(std::make_pair(xmlFeaturesNotAvailable, "XML features are not available"));
 		return m;
 	}
 
 	static std::map<OtherError, const char*> mapErrorMsg;
 
 protected:
-	
+
 	OtherError _errorType;
 };
 
