@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Utilities/maths/NEWMAT.h  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -101,6 +101,10 @@ public:
 	SymmetricMatrix(int nrow) {
 		_value = new NEWMAT::SymmetricMatrix(nrow);
 	}
+	// better 4 Inverse(), it avoids some memory leaks...
+	SymmetricMatrix(NEWMAT::SymmetricMatrix* mx) {
+		_value = mx;
+	}
 	
 	~SymmetricMatrix() {
 		if (_value)
@@ -122,8 +126,9 @@ public:
 		int _s_pbDimension = _value->Nrows();
 		NEWMAT::SymmetricMatrix* value_Inv = new NEWMAT::SymmetricMatrix(_s_pbDimension);
 		*value_Inv << _value->i();
-		SymmetricMatrix* invMat = new SymmetricMatrix(_s_pbDimension);
-		invMat->_value = value_Inv;
+		//SymmetricMatrix* invMat = new SymmetricMatrix(_s_pbDimension);
+		//invMat->_value = value_Inv; //buggy, it generates memory leaks :-(
+        SymmetricMatrix* invMat = new SymmetricMatrix(value_Inv);
 		return invMat;
 	}
 	
